/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#include <sanity.h>

#include <ctype.h>
#include <qlineedit.h>
#include <qpushbutton.h>

#include "addrbookentry.h"
#include "address.h"
#include "addressbook.h"

/**
 *=------------------------------------------------------------------------=
 * AddressBookEntry::AddressBookEntry
 *=------------------------------------------------------------------------=
 * this is the dialog you use to create a new entry in the AddressBook
 * database.
 *
 * Parameters:
 *      - as per QDialog::QDialog
 */
AddressBookEntry::AddressBookEntry
(
    QWidget *parent,
    const char *name,
    bool modal,
    WFlags flags
)
: AddressBookEntryDialog(parent, name, modal, flags)
{

    QObject::connect(okB, SIGNAL(clicked()), this, SLOT(accept()));
    QObject::connect(cancelB, SIGNAL(clicked()), this, SLOT(reject()));

    nameE->setFocus();
}

/**
 *=------------------------------------------------------------------------=
 * AddressBookEntry::AddressBookEntry
 *=------------------------------------------------------------------------=
 * overloaded version that allows you to specify incoming values ...
 *
 * Parameters:
 *      const char *                        - [in] full SMTP email address
 *      - as per QDialog::QDialog
 */
AddressBookEntry::AddressBookEntry
(
    const char *smtpAddress,
    QWidget *parent,
    const char *name,
    bool modal,
    WFlags flags
) : AddressBookEntryDialog(parent, name, modal, flags)
{

    const char *pstr;

    addressExtractEmailAddress(smtpAddress, pstr);
    if (pstr) {
        emailE->setText(pstr);
        localFree(pstr);
    }
    addressExtractUserNameCopy(smtpAddress, pstr);
    if (pstr) {
        nameE->setText(pstr);
        localFree(pstr);
    }


    QObject::connect(okB, SIGNAL(clicked()), this, SLOT(accept()));
    QObject::connect(cancelB, SIGNAL(clicked()), this, SLOT(reject()));

    nameE->setFocus();
}




/**
 *=------------------------------------------------------------------------=
 * AddressBookEntry::accept
 *=------------------------------------------------------------------------=
 * make sure they've entered valid values for the various info, and either
 * reject or accept.
 */
void AddressBookEntry::accept()
{
    if (emailE->text().length() <= 0) {
        errorShowError(E_INVALID_EMAILADDR);
        return;
    }

    AddressBookEntryDialog::accept();
}

/**
 *=------------------------------------------------------------------------=
 * AddressBookEntry::getItem
 *=------------------------------------------------------------------------=
 * return the information that was entered for this user.
 *
 * Parameters:
 *      AddressBookItem * &     - [out] the new item created.
 */
void AddressBookEntry::getItem
(
    AddressBookItem * &newItem
)
{
    K_ASSERT(emailE->text().length() > 0, "Checking shoulda caught this !!!\n");

    newItem = (AddressBookItem *)localAlloc(sizeof(AddressBookItem));
    if (!newItem) return;

    if (nameE->text().length() > 0)
        addressExtractNameParts((const char *)nameE->text(), newItem->firstName, newItem->lastName);
    if (emailE->text().length() > 0)
        newItem->emailAddress = copyString((const char *)emailE->text());
}




