/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#ifndef _ADDRESS_H_

#include <qstring.h>

#define MAX_EADDRESS_LEN    1024    // UNDONE: marcw, 9/20/2000 -- what's the real SMTP limit on this?


/**
 *=------------------------------------------------------------------------=
 *=------------------------------------------------------------------------=
 * Routines for getting information about addresses, etc...
 *=------------------------------------------------------------------------=
 *=------------------------------------------------------------------------=
 */


ERRCODE addressExtractEmailAddress(const char *addr, const char *&email); 
ERRCODE addressExtractNameParts(const char *, const char *&first, const char *&last);

/**
 * Given an arbitrary email address, try to figure out what the user
 * name is.  If there isn't one, just return the email address (cleaned
 * up a little bit, of course).
 */
void    addressExtractUserName(const char *, char *, int);
ERRCODE addressExtractUserNameCopy(const char *, const char *&);


/**
 * Takes a user name and email address, and generates an SMTP happy
 * type address like:
 *
 * "Bobo the Clown" <bobo@theclown.com.
 */
void    addressGenerateSmtp(const QString &userName, const char *emailAddress,
                               char *buf, unsigned int sizeofBuf);
ERRCODE addressGenerateSmtpCopy(const QString &userName, const char *emailAddress,
                                const char * &result);


/**
 * Given a first and last name, generate a full name for it.
 */
void    addressGenerateFullName(const char *first, const char *last,
                                char *buf, unsigned int sizeofBuf);


#define _ADDRESS_H_
#endif // _ADDRESS_H_


