/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#ifndef _ADDRESSBOOK_H_
#define _ADDRESSBOOK_H_

#include "kwindowbase.h"
#include <llist.h>

class QListView;
class QLineEdit;
class QLabel;


/**
 *=------------------------------------------------------------------------=
 * This is an entry in the address book.  More can be added as needed.
 *=------------------------------------------------------------------------=
 */
struct AddressBookItem {

    const char *firstName;
    const char *lastName;
    const char *emailAddress;

};



/**
 *=------------------------------------------------------------------------=
 * This is our main address book window thingie.  Very exciting.
 *=------------------------------------------------------------------------=
 */
class AddressBook : public KWindowBase {

    /**
     * This has to be here for all Qt objects.
     */
    Q_OBJECT
    DEBUG_TEST_DECL;

  public:
    AddressBook();
    virtual ~AddressBook();
    ERRCODE initialize();

    /**
     * Destroy an item and all of its storage.
     */
    static void nukeAddressBookItem(AddressBookItem *);

    /**
     * Get a list of the items, but don't copy all the data -- for short-term
     * use only
     */
    void getAddressListRef(LinkList<AddressBookItem *> &);

    /**
     * Shows the address book entry for the given email address/name.
     */
    void showAddressEntry(const char *, QWidget *parent);

    /**
     * Add the given full spec email address to the address book.  the
     * relevant information is parsed out of it.
     */
    ERRCODE addNewEntryFromAddress(const char *);


  protected:
    virtual void layoutComponents();

  private:
    QListView *listView;
    QLabel *searchLabel;
    QLineEdit *searchEdit;

    LinkList<AddressBookItem *> addresses;

    /**
     * Routines for loading and saving the address books ...
     */
    ERRCODE loadAddressDB();
    ERRCODE createBlankDB(const char *path);
    ERRCODE writeEntry(AddressBookItem *item);
    ERRCODE parseEntry(const char *buf, AddressBookItem * &newItem);

    /** 
     * Add the given entry to the view.
     */
    void addUIEntry(AddressBookItem *);
    
    /**
     * Find the given email address in our db.
     */
    ERRCODE findAddress(const char *emailAddress, AddressBookItem * &);



  private slots:
    void fileNew();
    void fileProperties();
    void fileDelete();
    void filePrint();
    void fileClose();

    void editCut();
    void editCopy();
    void editPaste();
    void editSelectAll();

    void helpHelp();
    void helpAbout();
};



#endif // _ADDRESSBOOK_H_



