/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#include <sanity.h>

#include <qlabel.h>
#include <qlistbox.h>
#include <qlistview.h>
#include <qpixmap.h>
#include <qpushbutton.h>

#include "address.h"
#include "addressbook.h"
#include "addrpicker.h"
#include "intl.h"
#include "kiltdown.h"
#include "localized.h"
#include "main.h"
#include "uiicons.h"


class APListViewItem : public QListViewItem {
  public:
    APListViewItem( QListView * parent, QString label1, 
                    QString label2 = QString::null, 
                    QString label3 = QString::null, 
                    QString label4 = QString::null, 
                    QString label5 = QString::null, 
                    QString label6 = QString::null, 
                    QString label7 = QString::null,
                    QString label8 = QString::null)
         : QListViewItem(parent, label1, label2, label3, label4, label5, label6,
                         label7, label8) {
    }
};


/**
 *=------------------------------------------------------------------------=
 * AddressPicker::AddressPicker
 *=------------------------------------------------------------------------=
 * initializes the dialog and sets up the few remaining UI things that are
 * missing.
 *
 * Parameters:
 *      STRINGID                    - [in]  the caption
 *      QWidget *                   - [in]  parent
 *      const char *                - [in]  name
 *      bool                        - [in]  modal
 *      WFlags                      - [in]  flags
 */
AddressPicker::AddressPicker
(
    STRINGID caption,
    QWidget *parent,
    const char *name,
    bool modal,
    WFlags flags
)
: AddressPickerDialog(parent, name, modal, flags)
{
    LinkList<AddressBookItem *> items;
    AddressBookItem *ali;
    AddressBook *b;
    char buf[520];
    ERRCODE er;

    setCaption(intlLoadStringX(caption));

    pixmapL->setPixmap(QPixmap(newaddresslgIcon));

    QObject::connect(okB, SIGNAL(clicked()), this, SLOT(accept()));
    QObject::connect(cancelB, SIGNAL(clicked()), this, SLOT(reject()));
    QObject::connect(addB, SIGNAL(clicked()), this, SLOT(addButtonClicked()));
    QObject::connect(removeB, SIGNAL(clicked()), this, SLOT(removeButtonClicked()));

    /**
     * Initialize the listview.
     */
    listView->addColumn(intlLoadStringX(ID_AB_FIELD_NAME), -1);//listView->width() / 2 - 2);
    listView->addColumn(intlLoadStringX(ID_AB_FIELD_EMAIL), -1);// listView->width() / 2 - 2);
    listView->setMultiSelection(true);
    listView->setSorting(0, true);

    /**
     * Now, we have to get the list of names from the Address Book and then go
     * and add them.
     */
    b = localMainWidget->getAddressBook();
    if (b) {
        b->getAddressListRef(items);
        er = items.firstElement(&ali);
        while (er == S_OK) {
            addressGenerateFullName(ali->firstName, ali->lastName, buf, sizeof(buf));
            new APListViewItem(listView, buf, ali->emailAddress);
            er = items.nextElement(&ali);
        }
    }

    DEBUG_TEST_START;
}


/**
 *=------------------------------------------------------------------------=
 * AddressPicker::~AddressPicker
 *=------------------------------------------------------------------------=
 */
AddressPicker::~AddressPicker()
{
    DEBUG_TEST_STOP;
}



/**
 *=------------------------------------------------------------------------=
 * AddressPicker::addButtonClicked
 *=------------------------------------------------------------------------=
 * the user has clicked on the add button.  Figure it out.
 */
void AddressPicker::addButtonClicked()
{
    char smtpAddress[1024];
    QListViewItem *item;

    /**
     * go whizzing through the list on the left, seeing if it's selected
     * or not.  If so, go and add it to the right.
     */
   item = listView->firstChild();
   while (item) {
       if (item->isSelected()) {
            addressGenerateSmtp(item->text(0), item->text(1),
                                smtpAddress, sizeof(smtpAddress));
            listBox->insertItem(smtpAddress);
       }

       item = item->nextSibling();
   }

}

/**
 *=------------------------------------------------------------------------=
 * AddressPicker::getAddressList
 *=------------------------------------------------------------------------=
 * returns a linked list of all email addresses clicked.  CALLER MUST FREE
 * STRINGS, AS THEY HAVE BEEN LOCALALLOC'D !!!!
 *
 * Parameters:
 *      LinkList<const char *> &        - [in]  where to put results.
 *
 * Output:
 *      ERRCODE
 */
ERRCODE AddressPicker::getAddressList
(
    LinkList<const char *> &list
)
{
    const char *pstr;
    unsigned int x;
    ERRCODE er;

    for (x = 0;  x < listBox->count(); x++) {

        pstr = listBox->text(x);
        if (pstr) {
            pstr = copyString(pstr);
            if (!pstr) goto OOM;

            er = list.addElement(pstr);
            if (FAILED(er)) goto OOM;
        }
    }

    return S_OK;

  OOM:
    nukeStringList(list);
    return E_OUTOFMEMORY;
}

/**
 *=------------------------------------------------------------------------=
 * AddressPicker::removeButtonClicked
 *=------------------------------------------------------------------------=
 * the remove button has been clicked.
 */
void AddressPicker::removeButtonClicked()
{
    QListBoxItem *item;
    unsigned int x = 0;
    
    /**
     * Whiz through the list removing elements.
     */
    for (x = 0; x < listBox->count(); x++) {

        if ((item = listBox->item(x)) != NULL 
            && listBox->isSelected(item)) {
            listBox->takeItem(item);
            x--;
        }
    }
}




