/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#ifndef _ATTACHMENT_H_
#define _ATTACHMENT_H_

#include <sanity.h>

#include "mime.h"

class QPixmap;

/** 
 * This class defines an attachment to a message or article.  It can encode
 * itself or decode itself from base64 and uuencode formats.  Sometimes it
 * will store itself as binary, others text, in the interest of efficiency.
 */


class Attachment {

    DEBUG_TEST_DECL;

  public:
    Attachment(const char *fullPath);
    Attachment(const char *, BYTE *, int, MimeEncoding, MIMETYPE);
    virtual ~Attachment();

    /**
     * public routines.
     */
    ERRCODE getBinaryDataRef(BYTE **);
    ERRCODE getBinarySize(int &);

    ERRCODE getEncoding(MimeEncoding &);
    ERRCODE getMimeType(MIMETYPE &);

    ERRCODE getFileName(const char **);
    ERRCODE getFileNameLen(int *);
    ERRCODE getFullPath(const char **);

    char *getPrintableSize();

    QPixmap *chooseIcon();

    ERRCODE saveToFile(const char *);

    /**
     * Unfortuantely, these objects can be waaaaay too big to copy around
     * all the time, so we're going to use some lifetime management routines
     * here, namely an addRef() and release() type scheme.  If you want to 
     * hold on to this object, then call addRef().  When you're done with it,
     * call release().  When the refcount gets to zero, it destroys itself.
     */
    virtual int addRef() { return m_cref++; }
    virtual int release() { int a = --m_cref;  if (!a) delete this; return a; }


  private:
    const char *fullPath;                        // usually just a filename.
    char sizeBuf[64];                        // to store a size string.
    MimeEncoding encoding;
    MIMETYPE type;
    BYTE *data;
    int size;
    int m_cref;

};


#endif // _ATTACHMENT_H_


