/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#include <sanity.h>

#include <ctype.h>

#include "attachment.h"
#include "deencode.h"
#include "mailmessage.h"
#include "mime.h"
#include "netapis.h"



/**
 * this is the table that gives us the mapping for the 64 ascii characters
 * into base 64 encoding.
 */
BYTE byteFromChar [] = {

  /* 0 -  09 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  /* 10 - 19 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  /* 20 - 29 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  /* 30 - 39 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  /* 40 - 49 */ 0xff, 0xff, 0xff, 62  , 0xff, 0xff, 0xff, 63  , 52  , 53  ,
  /* 50 - 59 */ 54  , 55  , 56  , 57  , 58  , 59  , 60  , 61  , 0xff, 0xff,
  /* 60 - 69 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0   , 1   , 2   , 3   , 4   ,
  /* 70 - 79 */ 5   , 6   , 7   , 8   , 9   , 10  , 11  , 12  , 13  , 14  ,
  /* 80 - 89 */ 15  , 16  , 17  , 18  , 19  , 20  , 21  , 22  , 23  , 24  ,
  /* 90 - 99 */ 25  , 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 26  , 27  , 28  ,
  /* 100 -109*/ 29  , 30  , 31  , 32  , 33  , 34  , 35  , 36  , 37  , 38  ,
  /* 110 -119*/ 39  , 40  , 41  , 42  , 43  , 44  , 45  , 46  , 47  , 48  ,
  /* 120 -129*/ 49  , 50  , 51  , 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  /* 0 -  09 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  /* 0 -  09 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  /* 0 -  09 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  /* 0 -  09 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  /* 0 -  09 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  /* 0 -  09 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  /* 0 -  09 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  /* 0 -  09 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  /* 0 -  09 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  /* 0 -  09 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  /* 0 -  09 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  /* 0 -  09 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  /* 0 -  09 */ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
};

/**
 * this table gives us the mapping from 6 bit binary values to characters
 * in the base64 encoding scheme.
 */
char charFromByte [] = {
    'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N',
    'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z', 'a', 'b',
    'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p',
    'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z', '0', '1', '2', '3',
    '4', '5', '6', '7', '8', '9', '+', '/'
};


/**
 *=------------------------------------------------------------------------=
 * base64Decode
 *=------------------------------------------------------------------------=
 * given an incoming character stream that is in base64 format, decode it
 * now.
 *
 * Parameters:
 *      const char *                - [in]  terminating separator.
 *      int *                       - [out] the size of the attachment.
 *      const char **               - [out] the decoded section.
 *
 * Output:
 *      ERRCODE
 */
ERRCODE base64Decode
(
    const char *separator,
    int *size,
    const char **body
)
{
    int cloop, cheld = 0, cwrite = 0, cread;
    char inputBuf[NET_MAXLINELEN];
    BYTE byteBuf[BUF_PIECE];
    BOOL badData = FALSE;
    BOOL fDone = FALSE;
    BYTE holdVals[4];
    BYTE holdByte[3];
    ERRCODE er;
    int len = 0;

    BYTE *outbuf = NULL;
    int outbufsize = 0;
    int cwritten = 0;

    /**
     * arg checking
     */
    if (!body || !separator) return E_PARAM;

    len = strlen(separator);

    /**
     * now, loop through the characters, converting them into byte triplets,
     * ignoring white space.
     */
    do {
        /**
         * read in a chunk of data
         */							     
        mimeReader.readLine(inputBuf, sizeof(inputBuf), cread);
        if (inputBuf[0] == '\0') {
            er = E_NET_UNEXPECTED;
            goto Error;
        }
        
        cloop = 0;
        cwrite = 0;
        while (inputBuf[cloop] != '\0' && inputBuf[cloop] != '\r'
               && inputBuf[cloop] != '\n') {

            /**
             * If the line is a separator line, then we are done.  this
             * might very well be premature if the base64 encoding isn't
             * properly terminated with '=' signs.
             */
            if (separator && !strncasecmp(inputBuf, separator, len)) {
                fDone = true;
                break;
            }

            if (!isspace(inputBuf[cloop])) {

                /**
                 * copy over the character unless it's a '='
                 */
                if (inputBuf[cloop] != '=') {
                    holdVals[cheld] = byteFromChar[inputBuf[cloop]];
                    cheld++;
                } else {
                    fDone = TRUE;
                }

                /**
                 * see if there was some corrupt data and warn the
                 * caller about it
                 */
                if (holdVals[cheld] == 0xff)
                    badData = TRUE;

                /**
                 * if we have enough to make three bytes or we're at the end
                 * of the stream, then we're happy campers!
                 */
                if (cheld == 4 || inputBuf[cloop] == '=') {

                    switch (cheld) {
                        case 4:
                            holdByte[2] = holdVals[3]
                                          | ((holdVals[2] & 0x3) << 6);
                        case 3:
                            holdByte[1] = ((holdVals[2] & 0x3c) >> 2)
                                          | ((holdVals[1] & 0xf) << 4);
                        case 2:
                            holdByte[0] = ((holdVals[1] & 0x30) >> 4)
                                          | (holdVals[0] << 2);
                            break;

                        default:
                            fprintf(stderr, "%d\n", cheld);
                            K_FAIL("base64Decode: This should never happen");
                    }

                    /**
                     * write out the appropriate number of bytes
                     */
                    memcpy(byteBuf + cwrite, holdByte, cheld - 1);
                    cwrite += (cheld - 1);
                    cheld = 0;
                }
            }

            if (fDone == TRUE) break;
            cloop++;
        }

        er = ensureBufferSize((char **)&outbuf, &outbufsize, cwritten + cwrite, BUFFER_INCREMENT);
        GOTO_ON_FAILURE(er, Error);
        memcpy(outbuf + cwritten, byteBuf, cwrite);
        cwritten += cwrite;

    } while (!fDone);

    
    /**
     * Pass on out the fullly decoded section.
     */
    *body = (const char *)outbuf;
    *size = cwritten;

    /**
     * Finally, get ourselves to the terminating MIME separator
     */
    while (1) {

        if (!strncasecmp(inputBuf, separator, len)) break;
        mimeReader.readLine(inputBuf, sizeof(inputBuf), cread);
        if (inputBuf[0] == '\0') {
            er = E_NET_UNEXPECTED;
            goto Error;
        }
    }
    er = S_OK;

  Error:
    if (FAILED(er)) { if (outbuf) localFree(outbuf); }
    return er;
}

/**
 *=------------------------------------------------------------------------=
 * base64Encode
 *=------------------------------------------------------------------------=
 * given a blob in binary format, encode it to base64 on the given output
 * stream.
 *
 * Parameters:
 *      int                     - [in]  network socket to write to.
 *      const char *            - [in]  blob to write out.
 *      int                     - [in]  size of the blob
 *
 * Output:
 *      ERRCODE
 */
ERRCODE base64Encode
(
    int socketfd,
    const char *blob,
    int size
)
{
    BYTE outLine[80];
    int cloop, result;
    int fixedSize;
    int x;

    /**
     * now grab three bytes at a time and then write them out
     */
    cloop = 0;
    fixedSize = size - (size % 3);
    x = 0;
    while (cloop < fixedSize) {

        outLine[x++] = charFromByte[(blob[cloop] & 0xfc) >> 2];
        outLine[x++] = charFromByte[((blob[cloop] & 0x3) << 4)
                                    | ((blob[cloop + 1] & 0xf0)
                                       >> 4)];
        outLine[x++] = charFromByte[((blob[cloop + 1] & 0xf) << 2)
                                    | ((blob[cloop + 2] 
                                       & 0xc0) >>6)];
        outLine[x++] = charFromByte[(blob[cloop + 2] & 0x3f)];


        if (x == 76) {
            outLine[76] = '\r';
            outLine[77] = '\n';
            outLine[78] = '\0';
            result = networkWrite(socketfd, outLine, 78);
            if (result == -1) {
                perror("networkWrite: ");
                return E_NET_ERR;
            }
            x = 0;
        }

        cloop += 3;
    }

    /**
     * Tie off the end if the file size isn't a clean multiple of 3
     */
    switch (size % 3) {
        case 2:
            outLine[x++] = charFromByte[(blob[cloop] & 0xfc) >> 2];
            outLine[x++] = charFromByte[((blob[cloop] & 0x3) << 4)
                                      | ((blob[cloop + 1] 
                                         & 0xf0) >> 4)];
            outLine[x++] = charFromByte[(blob[cloop + 1] & 0xf) << 2];
            outLine[x++] = '=';
            break;
        case 1:
            outLine[x++] = charFromByte[(blob[cloop] & 0xfc) >> 2];
            outLine[x++] = charFromByte[(blob[cloop] & 0x3) << 4];
            outLine[x++] = '=';
            outLine[x++] = '=';
            break;
        default:
            break;
    }

    /**
     * Write out whatever we've got left.
     */
    outLine[x++] = '\r';
    outLine[x++] = '\n';
    outLine[x] = '\0';
    result = networkWrite(socketfd, outLine, x);
    if (result == -1) {
        perror("networkWrite: ");
        return E_NET_ERR;
    }

    /**
     * And tie it off with a couple of blank lines.
     */
    result = networkWrite(socketfd, "\r\n\r\n", 4);
    if (result == -1) {
        perror("networkWrite: ");
        return E_NET_ERR;
    }

    return S_OK;
}







/**
 *=------------------------------------------------------------------------=
 * jumbleString
 *=------------------------------------------------------------------------=
 * extremely feeble attempt to encode a string on the local disk.  It is more
 * intended to keep prying eyes from quickly seeing what the name is.  This
 * should be hidden by file permissions or something like that as well.
 *
 * Parameters:
 *      const char *                    - [in]  jumble me
 *
 * Output:
 *      const char *
 */
const char *jumbleString
(
    const char *encodeMe
)
{
    char outputBuf[256];
    int cloop;
    int x = 0;

    int length = strlen(encodeMe);
    if ((unsigned int)length > ((sizeof(outputBuf) / 4) * 3)) {
        return NULL;
    }

    /**
     * now grab three bytes at a time and then write them out
     */
    cloop = 0;
    while (cloop < (length - (length % 3))) {

        outputBuf[x++] = charFromByte[(encodeMe[cloop] & 0xfc) >> 2];
        outputBuf[x++] = charFromByte[((encodeMe[cloop] & 0x3) << 4)
                                  | ((encodeMe[cloop + 1] & 0xf0)
                                     >> 4)];
        outputBuf[x++] = charFromByte[((encodeMe[cloop + 1] & 0xf) << 2)
                                  | ((encodeMe[cloop + 2] 
                                     & 0xc0) >>6)];
        outputBuf[x++] = charFromByte[(encodeMe[cloop + 2] & 0x3f)];
        cloop += 3;
    }

    switch (length % 3){
        case 2:
            outputBuf[x++] = charFromByte[(encodeMe[cloop] & 0xfc) >> 2];
            outputBuf[x++] = charFromByte[((encodeMe[cloop] & 0x3) << 4)
                                      | ((encodeMe[cloop + 1] 
                                         & 0xf0) >> 4)];
            outputBuf[x++] = charFromByte[(encodeMe[cloop + 1] & 0xf) << 2];
            outputBuf[x++] = '=';
            break;
        case 1:
            outputBuf[x++] = charFromByte[(encodeMe[cloop] & 0xfc) >> 2];
            outputBuf[x++] = charFromByte[(encodeMe[cloop] & 0x3) << 4];
            outputBuf[x++] = '=';
            outputBuf[x++] = '=';
            break;
    }

    outputBuf[x] = '\0';
    return copyString(outputBuf);
}


/**
 *=------------------------------------------------------------------------=
 * unjumbleString
 *=------------------------------------------------------------------------=
 * extremely feeble attempt to encode a string on the local disk.  It is more
 * intended to keep prying eyes from quickly seeing what the name is.  This
 * should be hidden by file permissions or something like that as well.
 *
 * Parameters:
 *      const char *                    - [in]  unjumble me
 *
 * Output:
 *      const char *
 */
const char *unjumbleString
(
    const char *decodeMe
)
{
    int cloop, cheld;
    char outputBuf[256];
    int fDone = 0;
    unsigned char holdVals[4];
    int x;

    /**
     * now, loop through the characters, converting them into byte triplets,
     * ignoring white space.
     */
    x = 0; cloop = 0; cheld =0;
    while (decodeMe[cloop] != '\0') {

        if (!isspace(decodeMe[cloop])) {

            /**
             * copy over the character unless it's a '='
             */
            if (decodeMe[cloop] != '=') {
                holdVals[cheld] = byteFromChar[decodeMe[cloop]];
                cheld++;
            } else {
                fDone = 1;
            }

            /**
             * if we have enough to make three bytes or we're at the end
             * of the stream, then we're happy campers!
             */
            if (cheld == 4 || decodeMe[cloop] == '=') {

                switch (cheld) {
                    case 4:
                        outputBuf[x + 2] = holdVals[3]
                                      | ((holdVals[2] & 0x3) << 6);
                    case 3:
                        outputBuf[x + 1] = ((holdVals[2] & 0x3c) >> 2)
                                      | ((holdVals[1] & 0xf) << 4);
                    case 2:
                        outputBuf[x] = ((holdVals[1] & 0x30) >> 4)
                                      | (holdVals[0] << 2);
                        break;
                }

                x += (cheld - 1);
                cheld = 0;
            }
        }

        if (fDone) break;
        cloop++;
    }

    outputBuf[x] = '\0';
    return copyString(outputBuf);
}



