/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#include <sanity.h>

#include <ctype.h>
#include <qapplication.h>
#include <qlabel.h>
#include <qprogressbar.h>

#include "compacting.h"
#include <ifolder.h>
#include "main.h"

#ifdef _KILTDOWN_USEKDE
#include <kapp.h>
#endif // _KILTDOWN_USEKDE


/**
 * We'll use this to actually start the compacting.
 */
class BeginCompactingEvent : public QEvent {
  public:
    BeginCompactingEvent() : QEvent(User) { }
};


/**
 *=------------------------------------------------------------------------=
 * Compacting::Compacting
 *=------------------------------------------------------------------------=
 * initializes the dialog.  This dialog is used to show the progress of
 * folder compacting operations.
 *
 * Parameters:
 *      - As per QDialog::QDialog
 */
Compacting::Compacting
(
    QWidget *parent,
    const char *name,
    bool modal,
    WFlags flags
)
: CompactingDialog(parent, name, modal, flags)
{
    entryList = NULL;
    entryCount = 0;
}

/**
 *=------------------------------------------------------------------------=
 * Compacting::~Compacting
 *=------------------------------------------------------------------------=
 * clean up.
 */
Compacting::~Compacting()
{
fprintf(stderr, "calling destructor !!!\n");
    freeEntryList();
}

/**
 *=------------------------------------------------------------------------=
 * Compacting::beginCompacting
 *=------------------------------------------------------------------------=
 * whips through our list of folders and starts compacting them.
 */
void Compacting::beginCompacting()
{
    const char *folderName;
    ERRCODE er;

    /**
     * Whip through the list of folders we've got and compact!!!
     */
    for (int x = 0; x < entryCount; x++) {

        /**
         * Set up the display
         */
        accountValueL->setText(entryList[x].accountName);
        entryList[x].folder->getDisplayName(&folderName);
        folderValueL->setText(folderName);
        mainProgress->setProgress(mainProgress->progress() + 1);
        localApplication->processEvents();
        localFree(folderName);

        /**
         * nOw compact it.
         */
        er = entryList[x].folder->compact();
        if (FAILED(er)) {
            errorShowError(er);
            break;
        }
    }
    
    /**
     * We're done -- hide the dialog and go away
     */
    this->accept();
}


/**
 *=------------------------------------------------------------------------=
 * Compacting::event
 *=------------------------------------------------------------------------=
 * we override this so we can get the event we sent ourselves.
 *
 * Parameters:
 *      QEvent *                - [in]  the event that is being sent.
 *
 * Output:
 *      bool                    - true if we're stealing it.
 */
bool Compacting::event
(
    QEvent *event
)
{
    /**
     * IF it's one of ours, begin processing.
     */
    if (event != NULL && dynamic_cast<BeginCompactingEvent *>(event) != NULL) {
        beginCompacting();
        return true;
    }

    /**
     * Otherwise, we don't want it, so just pass it on.
     */
    return CompactingDialog::event(event);
}

/**
 *=------------------------------------------------------------------------=
 * Compacting::exec
 *=------------------------------------------------------------------------=
 * we need to send a message to ourselves to tell us to start compacting
 * once the dialog is all up and initialized.
 */
int Compacting::exec()
{
    localApplication->postEvent(this, new BeginCompactingEvent());
    return CompactingDialog::exec();
}

/**
 *=------------------------------------------------------------------------=
 * Compacting::freeEntryList
 *=------------------------------------------------------------------------=
 * cleans up.
 */
void Compacting::freeEntryList()
{
    for (int x = 0; x < entryCount; x++) {
        if (entryList[x].accountName) localFree(entryList[x].accountName);
    }

    if (entryList != NULL) localFree(entryList);
    entryList = NULL;
    entryCount = 0;
}


/**
 *=------------------------------------------------------------------------=
 * Compacting::setEntries
 *=------------------------------------------------------------------------=
 * sets the entry list we're going to work with ... it's really an array, but
 * i like to call it a liast.
 *
 * Parameters:
 *      int                     - [in]  count of entries
 *      CompactEntry *          - [in]  array of entries to compact.
 */
void Compacting::setEntries
(
    int entryCount,
    CompactEntry *entryList
)
{
    freeEntryList();

    this->entryCount = entryCount;
    this->entryList = entryList;
    mainProgress->setTotalSteps(entryCount);
}


