/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#ifndef _COMPACTING_H_
#define _COMPACTING_H_

#include "compacting.dlg.h"


class IFolder;

/**
 * This struct describes a folder to be compacted.
 */
struct CompactEntry {
    const char *accountName;
    IFolder *folder;
};


/**
 *=------------------------------------------------------------------------=
 * Compacting
 *=------------------------------------------------------------------------=
 * A Simple dialog that shows the progress of compacting operations with
 * a cute little progress bar, etc ...
 */
class Compacting : public CompactingDialog {

  public:
    Compacting(QWidget *parent, const char *name, bool modal, WFlags f);
    ~Compacting();

    /**
     * Pass in an array of folders to be compacted here, and the dialog
     * will whip through them compacting them all.  We want to do it this
     * way because we want the dialog to be modal, so that nothing else
     * in the UI can occur while we're working away with this.
     */
    void setEntries(int entryCount, CompactEntry *entryList);

    /**
     * Overridden to send ourselves a message.
     */
    int exec();


  protected:
    /**
     * So we can get the event we sent ourselves.
     */
    virtual bool event(QEvent *e);


  private:
    CompactEntry *entryList;
    int entryCount;


    /**
     * Private methods.
     */
    void beginCompacting();
    void freeEntryList();
};



#endif // _COMPACTING_H_


