/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#ifndef _DBMGR_H_
#define _DBMGR_H_

#include <db.h>

/** 
 * This file contains routines that do their darndest to ensure the stability
 * of the database files.  In particular, on abnormal program termination, 
 * these routines will sync() up the databases before we die.
 */
ERRCODE dbmgrOpenDatabase(DB * & database, const char *path, bool create,
                          int mode);
ERRCODE dbmgrCloseDatabase(DB * database);



/**
 * DANGER DANGER DANGER -- THIS SHOULD ONLY BE CALLED WHEN THE PROCESS IS 
 * GOING AWAY (i.e. in a signal handler).
 *  THIS ROUTINE INVALIDATES ALL "DB *" POINTERS HELD BY FolderDB instances
 *  AND SHOULD THUS BE CONSIDERED VERY BAD.  THIS IS A LAST RESORT TO SYNC
 *  UP AND SAVE OUT DATABASES ON CRASH.
 */
void dbmgrSyncDatabasesOnDeath();



#endif // _DBMGR_H_


