/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#ifndef _DEENCODE_H_
#define _DEENCODE_H_


/**
 * This file contains routines that will be used for encoding or decoding
 * various parts of messages.
 */

/**
 * Forward decls
 */
class IReader;



/**
 *=------------------------------------------------------------------------=
 * Seven Bit Routines
 *=------------------------------------------------------------------------=
 */
ERRCODE sevenBitDecode(const char *sep, int *, const char **body);
ERRCODE sevenBitEncode(int, int, const char *body, int);

/**
 *=------------------------------------------------------------------------=
 * Quoted Printable Routines.
 *=------------------------------------------------------------------------=
 */
ERRCODE quotedPrintableDecode(const char *sep, int *, const char **body);
ERRCODE quotedPrintableEncode(int, int, const char *body, int);


/**
 *=------------------------------------------------------------------------=
 * Base64 Routines
 *=------------------------------------------------------------------------=
 */
ERRCODE base64Decode(const char *sep, int *, const char **body);
ERRCODE base64Encode(int, const char *body, int);

/**
 *=------------------------------------------------------------------------=
 * UUencode Routines.
 *=------------------------------------------------------------------------=
 */
ERRCODE uuencodeDecode(const char *sep, int *, const char **body);
ERRCODE uuencodeEncode(int, const char *body, int);

/**
 *=------------------------------------------------------------------------=
 * Random routines
 *=------------------------------------------------------------------------=
 */
const char *jumbleString(const char *);
const char *unjumbleString(const char *);



#define BUFFER_INCREMENT 8192
#define BUF_PIECE 3072


#endif // _DEENCODE_H_


