/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#include "downloaddlg.h"

#include <qlabel.h>
#include <qprogressbar.h>
#include <qpushbutton.h>
#include <qtextbrowser.h>

#include "kiltdown.h"
#include "main.h"
#include "passworddlg.h"


/**
 *=------------------------------------------------------------------------=
 * DownloadDialog::DownloadDialog
 *=------------------------------------------------------------------------=
 * initialize everything and hook up all the Ui widgies.
 *
 * Parameters:
 *      QWidget *               - [in]  our parent widget.
 */
DownloadDialog::DownloadDialog
(
    QWidget *parent
)
: DownloadDlg(parent, "dd", false, 0)
{

    /**
     * Hook up various important events
     */
    QObject::connect(hideB, SIGNAL(clicked()), this, SLOT(hide()));
    QObject::connect(stopB, SIGNAL(clicked()), this, SLOT(stopClicked()));
    QObject::connect(detailsB, SIGNAL(clicked()), this, SLOT(detailsClicked()));

    this->mainProgressB->setProgress(0);
}

/**
 *=------------------------------------------------------------------------=
 * DownloadDialog::~DownloadDialog
 *=------------------------------------------------------------------------=
 */
DownloadDialog::~DownloadDialog()
{
}


/**
 *=------------------------------------------------------------------------=
 * DownloadDialog::addMessage
 *=------------------------------------------------------------------------=
 * adds a message to the edit box
 * 
 * Parameters:
 *      const char *                - [in]  addme
 */
void DownloadDialog::addMessage
(
    const char *message
)
{
    this->detailsTextArea->append(message);
}


/**
 *=------------------------------------------------------------------------=
 * DownloadDialog::clear
 *=------------------------------------------------------------------------=
 * clear out the details text browser.
 */
void DownloadDialog::clear()
{
    this->detailsTextArea->setText(QString::null);
}

/**
 *=------------------------------------------------------------------------=
 * DownloadDialog::detailsClicked
 *=------------------------------------------------------------------------=
 * the details button was clicked.  deal with it.
 */
void DownloadDialog::detailsClicked()
{

}


/**
 *=------------------------------------------------------------------------=
 * DownloadDialog::initAccount
 *=------------------------------------------------------------------------=
 * they are moving to a new account -- change the text.
 *
 * Parameters:
 *      const char *                - [in]  new account name.
 */
void DownloadDialog::initAccount
(
    const char *acctName
)
{
    this->generalL->setText(acctName);
    this->mainProgressB->setProgress(0);
    this->mainProgressB->setTotalSteps(100);
}

/**
 *=------------------------------------------------------------------------=
 * DownloadDialog::nextMessage
 *=------------------------------------------------------------------------=
 * increases our progressbar one!
 */
void DownloadDialog::nextMessage()
{
    this->mainProgressB->setProgress(this->mainProgressB->progress() + 1);
}

/**
 *=------------------------------------------------------------------------=
 * DownloadDialog::setDisplayText
 *=------------------------------------------------------------------------=
 * sets the detailed text that we're going to display now.
 *
 * Parameters:
 */
void DownloadDialog::setDisplayText
(
    const char *text
)
{
    this->detailedL->setText(text);
}

/**
 *=------------------------------------------------------------------------=
 * DownloadDialog::setMessageCount
 *=------------------------------------------------------------------------=
 * sets the message count that we're going be working with for this account.
 * Resets the progress to zero as well.
 *
 * Parameters:
 *      int                     - [in]  count for this acct.
 */
void DownloadDialog::setMessageCount
(
    int count
)
{
    this->mainProgressB->setTotalSteps(count);
    this->mainProgressB->setProgress(0);
}


/**
 *=------------------------------------------------------------------------=
 * DownloadDialog::showPasswordDialog
 *=------------------------------------------------------------------------=
 * shows the password dialog for the given account with the given default
 * name.  Returns the two given strings.  CALLER frees.
 *
 * Parameters:
 *      const char *                    - [in]  account name.
 *      const char *                    - [in]  default name.
 *      const char * &                  - [out] newly entered user name
 *      const char * &                  - [out] newly entereed password
 *      bool &                          - [out] should this be remembered
 *
 * Output:
 *      ERRCODE
 */
ERRCODE DownloadDialog::showPasswordDialog
(
    const char *account,
    const char *name,
    const char * &userName,
    const char * & userPassword,
    bool & remember
)
{
    PasswordDialog pldg(localMainWidget, account, name);
    int ret;

    userName = userPassword = NULL;
    remember = false;

    /**
     * show the dialog
     */
    ret = pldg.exec();

    /**
     * Did they cancel or enter some data?
     */
    if (ret == QDialog::Accepted) {
        return pldg.getInput(userName, userPassword, remember);
    } else {
        return S_FALSE;
    }

    // dead code
}

/**
 *=------------------------------------------------------------------------=
 * DownloadDialog::stopClicked
 *=------------------------------------------------------------------------=
 * the stop button was clicked.  Deal with it.
 */
void DownloadDialog::stopClicked()
{

}



