/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#include "errordialog.h"



#include <qhbox.h>
#include <qlabel.h>
#include <qpushbutton.h>
#include <qvbox.h>

#include "localized.h"
#include "uiicons.h"





/**
 *=------------------------------------------------------------------------=
 *                          ErrorDialog routines
 *=------------------------------------------------------------------------=
 */


/**
 *=------------------------------------------------------------------------=
 * ErrorDialog::ErrorDialog
 *=------------------------------------------------------------------------=
 * Initializes stuff.
 */
ErrorDialog::ErrorDialog()
: QDialog(0,0, true, WStyle_NoBorder)
{
    this->errorLabel = NULL;
    this->imgLabel = NULL;
    this->hbox1 = NULL;
    this->hbox2 = NULL;
    this->more = NULL;
    this->vbox = NULL;
    this->ok = NULL;
}

/**
 *=------------------------------------------------------------------------=
 * ErrorDialog::~ErrorDialog
 *=------------------------------------------------------------------------=
 * Initializes stuff.
 */
ErrorDialog::~ErrorDialog()
{
    if (errorLabel) delete errorLabel;
    if (imgLabel) delete imgLabel;
    if (more) delete more;
    if (ok) delete ok;
}


/**
 *=------------------------------------------------------------------------=
 * ErrorDialog::initialize
 *=------------------------------------------------------------------------=
 * Initializes stuff.
 *
 * Parameters:
 *      const char *                - [in]  base info
 *      const char *                - [in]  ex info
 *
 * Output:
 *      ERRCODE
 */
ERRCODE ErrorDialog::initialize
(
    const char * base,
    const char * ex
)
{
    const char *pstr;

    vbox = new QVBox(this);
    if (!vbox) return E_OUTOFMEMORY;
    vbox->setSpacing(5);
    vbox->setMargin(5);

    hbox1 = new QHBox(vbox);
    if (!hbox1) return E_OUTOFMEMORY;

    errorLabel = new QLabel(hbox1);
    if (!errorLabel) return E_OUTOFMEMORY;
    errorLabel->setTextFormat(Qt::RichText);
    errorLabel->setText(base);

    imgLabel = new QLabel(hbox1);
    if (!imgLabel) return E_OUTOFMEMORY;
    imgLabel->setAlignment(Qt::AlignCenter);
    imgLabel->setPixmap(QPixmap(sendmessagelgIcon));

    hbox2 = new QHBox(vbox);
    if (!hbox2) return E_OUTOFMEMORY;
    hbox2->setSpacing(15);
    hbox2->setMargin(5);

    ok = new QPushButton(hbox2);
    if (!ok) return E_OUTOFMEMORY;
    pstr = intlLoadString(ID_OK_TEXT);
    if (!pstr) return E_OUTOFMEMORY;
    ok->setText(pstr);
    localFree(pstr);

    more = new QPushButton(hbox2);
    if (!more) return E_OUTOFMEMORY;
    pstr = intlLoadString(ID_MORE_TEXT);
    if (!pstr) return E_OUTOFMEMORY;
    more->setText(pstr);
    localFree(pstr);

    vbox->setGeometry(0, 0, 375, 125);
    this->setBaseSize(QSize(375, 125));
    ok->setFocus();

    /**
     * Hook up signals
     */
    QObject::connect(ok, SIGNAL(clicked()), this, SLOT(accept()));
    QObject::connect(more, SIGNAL(clicked()), this, SLOT(showExInfo()));

    return S_OK;
}

/**
 *=------------------------------------------------------------------------=
 * ErrorDialog::resizeEvent
 *=------------------------------------------------------------------------=
 * being resized.
 *
 * Parameters:
 *      QResizeEvent *                  - [in]
 */
void ErrorDialog::resizeEvent
(
    QResizeEvent *event
)
{
    if (!event) return;
    QSize size = event->size();

    vbox->setGeometry(0, 0, size.width(), size.height());
}

/**
 *=------------------------------------------------------------------------=
 * ErrorDialog::showExInfo
 *=------------------------------------------------------------------------=
 * show more information about the error.
 */
void ErrorDialog::showExInfo()
{
    fprintf(stderr, "whoops\n");
}

