/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#ifndef _FILEUTIL_H_
#define _FILEUTIL_H_


#include "ireader.h"


/**
 * Copies a file.  
 */
ERRCODE fileCopyFile(const char *source, const char *dest);

/**
 * remove a file or directories and all the crap underneath it.  There is no
 * "kill this damn thing" API, unforunately.
 */
ERRCODE fileRmfr(const char *dirOrFile);



/**
 *=------------------------------------------------------------------------=
 * FileReader is an implementation of IReader over a local file.
 */
class FileReader : public IReader {

  public:
    FileReader(FILE *file, const char *fullPath, int maxLineLen);
    virtual ~FileReader();

    /**
     * IReader methods
     */
    virtual ERRCODE readLine(void *, unsigned int, int &cread);

  private:
    /**
     * Local instance data
     */
    FILE *file;
    const char *path;
    char *readBuf;
    int maxLineLen;

    /**
     * Returns the read buffer into which we should do initial reads.
     */
    char *getReadBuf();
};



#endif // _FILEUTIL_H_



