/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#include <sanity.h>

#include <qlineedit.h>
#include <qpushbutton.h>


#include "findtext.h"



/**
 *=------------------------------------------------------------------------=
 * FindText::FindText
 *=------------------------------------------------------------------------=
 * our cute little dialog for finding text.
 *
 * Parameters:
 *      - as per QDialog.
 */
FindText::FindText
(
    QWidget* parent,
    const char* name, 
    bool modal, 
    WFlags fl
) : FindTextDialog(parent, name, modal, fl)
{
    searchForE->setFocus();

    QObject::connect(this->cancelB, SIGNAL(clicked()), this, SLOT(reject()));
}



/**
 *=------------------------------------------------------------------------=
 * FindText::hookUpFindButton
 *=------------------------------------------------------------------------=
 * hooks up the find button so somebody can listen to it.
 *
 * Parameters:
 *      QObject *               - [in]  person with slot.
 *      const char *            - [in]  slot.
 */
void FindText::hookUpFindButton
(
    QObject *obj,
    const char *member
)
{
    QObject::connect(this->findB, SIGNAL(clicked()), obj, member);
}



/**
 *=------------------------------------------------------------------------=
 * FindText::unhookFindButton
 *=------------------------------------------------------------------------=
 * unhooks up the find button .
 *
 * Parameters:
 *      QObject *               - [in]  person with slot.
 *      const char *            - [in]  slot.
 */
void FindText::unhookFindButton
(
    QObject *obj,
    const char *member
)
{
    QObject::disconnect(this->findB, SIGNAL(clicked()), obj, member);
}




