/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
/**
 * This file defines some routines that we will use to localize strings 
 * within our UI.  I know there are a bajillion APIs out there to do this,
 * but I'm not 100% comfortable with msot of them, so I'll just use this, as
 * it's a good exercise in coding ...
 */
#include <sanity.h>


#include <miscutil.h>
#include <intl.h>

extern "C" const char * __intlStrings [];
extern int __intlAccelerators [];


/**
 *=------------------------------------------------------------------------=
 * intlLoadAccelerator
 *=------------------------------------------------------------------------=
 * load in an accelerator for our program.
 *
 * Parameters:
 *      int                         - [in]  ACCELID
 *
 * Output:
 *      int
 */
int intlLoadAccelerator
(
    int accelid
)
{
    return __intlAccelerators [accelid];
}


/**
 *=------------------------------------------------------------------------=
 * intlLoadString
 *=------------------------------------------------------------------------=
 * loads in the localized version of the given string.  Callee must free.
 *
 * Parameters:
 *	int		- [in]  the resource ID of the string to load.
 *
 * Output:
 *      const char *    - malloc'd string we retrieved.  CALLEE must FREE!!
 */
const char *intlLoadString
(
    int stringid
)
{
    return copyString(__intlStrings[stringid]);
}

/**
 *=------------------------------------------------------------------------=
 * intlLoadStringX
 *=------------------------------------------------------------------------=
 * loads in the localized version of the given string. 
 *
 * Parameters:
 *	int		- [in]  the resource ID of the string to load.
 *
 * Output:
 *      const char *
 */
const char *intlLoadStringX
(
    int stringid
)
{
    return __intlStrings[stringid];
}




