/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#ifndef _MAILCOLUMNS_H_
#define _MAILCOLUMNS_H_

/**
 * This file specifies the columns that are available to the mail subsystem.  
 * This is required to help with persistence, and choosing which ones can
 * be shown, etc ...
 */


/**
 * this is the list of all available columns.
 */
enum MailColumn {
    MC_ATTACHMENTS = 0,
    MC_STATUS,
    MC_PRIORITY,
    MC_FROM,
    MC_TO,
    MC_CC,
    MC_BCC,
    MC_SUBJECT,
    MC_RECEIVED,
    MC_SENT,
    MC_SIZE,
    MC_LAST = MC_SIZE
};

/**
 *=---------------------------------------------------------=
 * NOTE:  KEEP THIS THE SAME AS ColumnSorting IN KMAILLIST.H    
 *=---------------------------------------------------------=
 */
enum MailColumnSorting {
    MCS_NONE = 0,
    MCS_PRIMARY_UP = 1,
    MCS_PRIMARY_DOWN = 2,
    MCS_SECONDARY = 3,
    MCS_LAST = MCS_SECONDARY
};


/**
 * This is how we will describe columns in this file.
 */
struct MailColumnInfo {

    enum MailColumn which;
    bool fixed;
    int width;        // fixed = true
    double pct;       // fixed = false
    MailColumnSorting sort;
};


/**
 * The default values for all the columns.  Find the right one in here and
 * use the values.  This is only for adding a NEW column to an already 
 * existing set. 
 */
extern MailColumnInfo allColumnsDefaultValues[];

/**
 * the default set of columns that folders that show "from:" should display
 */
#define DEFAULT_FROM_COUNT    6
extern MailColumnInfo defaultFromColumnInfo[];

/**
 * The default set of columns that folders that show "To:" should display
 * (i.e. Outbox, sent items)
 */
#define DEFAULT_TO_COUNT      6
extern MailColumnInfo defaultToColumnInfo[];


/**
 * Shows a widget that lets the user select what columns they want to view for
 * the current folder.
 */
ERRCODE showMailColumnPicker();









#endif // _MAILCOLUMNS_H_
