/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#ifndef _MAILPROPS_H_
#define _MAILPROPS_H_

#include <sanity.h>

#include <qwidget.h>

class MailAccountInfo;
class QRadioButton;
class QPushButton;
class QComboBox;
class QCheckBox;
class QLineEdit;
class QGroupBox;
class QLabel;

/**
 *=------------------------------------------------------------------------=
 *        This file contains the pages for the Mail Properties Dialog      *
 *=------------------------------------------------------------------------=
 */


/**
 *=------------------------------------------------------------------------=
 * General account options.
 *=------------------------------------------------------------------------=
 */
class AccountInfoPage : public QWidget {

    Q_OBJECT;

  public:
    AccountInfoPage();
    virtual ~AccountInfoPage();
    ERRCODE initialize(const char *acctName, const char *acctDir, 
                       MailAccountInfo &info);
    ERRCODE getResults(const char *&acctName, MailAccountInfo &info);

  protected:
    void resizeEvent(QResizeEvent *);
    void paintEvent(QPaintEvent *);

  private:
    QLabel *accountNameL, *userNameL, *userOrganizationL, *emailAddressL,
           *signatureFileL;
    QLineEdit *accountNameE, *userNameE, *userOrganizationE, *emailAddressE,
              *signatureFileE;
    QPushButton *signatureFileP;

    const char *accountDirectory;
    const char *accountName;

  private slots:
    void buttonClicked();
};


/**
 *=------------------------------------------------------------------------=
 * Incoming POP server options.
 *=------------------------------------------------------------------------=
 */
class AccountIncomingPage : public QWidget {

    Q_OBJECT

  public:
    AccountIncomingPage();
    ~AccountIncomingPage();
    ERRCODE initialize(MailAccountInfo &info);
    ERRCODE getResults(MailAccountInfo &info);

    protected:
      void resizeEvent(QResizeEvent *);
      void paintEvent(QPaintEvent *);

  private:
    QLabel *typeOfServerL, *serverNameL, *accountInformationL, *popUserNameL,
        *popPasswordL, *deliveryL;
    QLineEdit *serverNameE, *popUserNameE, *popPasswordE;
    QCheckBox *rememberPasswordC, *leaveOnServerC, *dontDuplicateC;
    QComboBox *typeOfServerB;

  private slots:
    void leaveOnServerClicked();

};


/**
 *=------------------------------------------------------------------------=
 * Outgoing SMTP Server options
 *=------------------------------------------------------------------------=
 */
class AccountOutgoingPage : public QWidget {

    Q_OBJECT

  public:
    AccountOutgoingPage();
    ~AccountOutgoingPage();
    ERRCODE initialize(MailAccountInfo &info);
    ERRCODE getResults(MailAccountInfo &info);

    protected:
      void resizeEvent(QResizeEvent *);
      void paintEvent(QPaintEvent *);

  private:
    QLabel *serverNameL, *smtpUserNameL, *smtpPasswordL;
    QLineEdit *serverNameE, *smtpUserNameE, *smtpPasswordE;
    QCheckBox *rememberSmtpPasswordC, *serverNeedsAuthC;
    QRadioButton *usePopB, *useSpecifiedB;
    QGroupBox *frame;

  private slots:
    void serverNeedsAuthClicked();
    void usePopButtonClicked();
    void useSpecifiedButtonClicked();
};

/**
 *=------------------------------------------------------------------------=
 * Security options
 *=------------------------------------------------------------------------=
 */
class AccountSecurityPage : public QWidget {

  public:
    AccountSecurityPage();
    ~AccountSecurityPage();
    ERRCODE initialize();
    ERRCODE getResults(MailAccountInfo &info);

  private:
};

/**
 *=------------------------------------------------------------------------=
 * Advanced options.
 *=------------------------------------------------------------------------=
 */
class AccountAdvancedPage : public QWidget {

    Q_OBJECT


  public:
    AccountAdvancedPage();
    ~AccountAdvancedPage();
    ERRCODE initialize(MailAccountInfo &info);
    ERRCODE getResults(MailAccountInfo &info);

  protected:
    void resizeEvent(QResizeEvent *);
    void paintEvent(QPaintEvent *);

  private:
    QGroupBox *frame;
    QLabel *smtpPortL, *pop3L, *pop3PortL, *pop3SSLPortL, *serverTimeoutL, *secsL;
    QLineEdit *smtpPortE, *pop3PortE, *pop3SSLPortE, *timeoutE;
    QCheckBox *smtpUseSSLC;
    QRadioButton *regularPopB, *securePopB;
    
  private slots:
    void regularPopButtonClicked();
    void securePopButtonClicked();
};



#endif // _MAILPROPS_H_

