/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#ifndef _MAILVIEWER_H_
#define _MAILVIEWER_H_


/**
 * This window is used to view mail message in your folder.
 */
#include <sanity.h>

#include <qlabel.h>
#include <qlineedit.h>
#include <qmainwindow.h>
#include <qmenubar.h>


#include "kwindowbase.h"


/**
 * Forward decls.
 */
class Attachment;
class MailMessage;
class MailFolder;
class QIconView;
class QIconViewItem;
class QSplitter;
class FindText;
class SuperLabel;


class MailViewer : public KWindowBase {

    /**
     * This has to be here for all Qt objects.
     */
    Q_OBJECT

    DEBUG_TEST_DECL;

  public:

    /**
     * Initializes the UI for this viewer, given a MailMessage with which to
     * populate all the data.
     */
    ERRCODE initialize(MailMessage *);

    MailViewer(MailFolder *);
    virtual ~MailViewer();

  protected:
    /**
     * We override this to layout our own components.
     */
    virtual void layoutComponents();
    virtual void createdPopup(int, QPopupMenu *);
    virtual void keyPressEvent(QKeyEvent *);

  private:
    MailFolder *folder;
    MailMessage *message;
    MyMultiLineEdit *editBox;
    QIconView *attachmentView;
    QSplitter *contentSplitter;
    QPopupMenu *attachmentPopup;
    QToolButton *viewHtmlButton;
    QLabel *priorityLabel, *priorityPixLabel;
    QLabel *toLabel, *fromLabel, *ccLabel, *subjectLabel, *dateLabel;
    QLabel *dateValue, *subjectValue;
    SuperLabel *toValue, *fromValue, *ccValue;

    LinkList<Attachment *> attachments;

    FindText *findText;

    /**
     * Populates the window given a mail message.
     */
    ERRCODE populateFromMailMessage(MailMessage *);

    /**
     * Misc goo
     */
    QToolButton *getHtmlButton();
    int getIconViewSelectionCount();
    ERRCODE addAttachmentToDisplay(Attachment *);
    ERRCODE selectAttachDirectory(const char **pstr);
    ERRCODE selectAttachments(LinkList<Attachment *> &);

  private slots:
    /**
     * Menu/Toolbar Slots
     */
    void fileNew();
    void fileSave();
    void fileSaveAttach();
    void fileSend();
    void filePrint();
    void fileClose();

    void editCut();
    void editCopy();
    void editPaste();
    void editSelectAll();
    void editFindPerson();
    void editFindMessage();
    void editFindText();

    void viewPrevious();
    void viewNext();
    void viewAllHeaders();
    void viewHtmlContent();

    void toolsAddressBook();
    void toolsAddToAddressBook();

    void messageReply();
    void messageReplyAll();
    void messageForward();
    void messageDelete();

    void helpHelpMe();
    void helpHelp();
    void helpAbout();

    /**
     * Attachment viewer support
     */
    void rightIVButtonPressed(QIconViewItem *, const QPoint &);
    void doubleClickedIV(QIconViewItem *);
    void selectAllAttachments();
    void openAttachment();
    void saveAttachment();

    /**
     * menu popup slots
     */
    void aboutToShowFileMenu();
    void aboutToShowEditMenu();
    void aboutToShowViewMenu();

    /**
     * Search for Text Dialog.
     */
    void searchForText();
};





#endif // _MAILVIEWER_H_


