/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#include <sanity.h>

#include "attachment.h"
#include "deencode.h"
#include <llist.h>
#include "mime.h"
#include "netapis.h"


/**
 *=------------------------------------------------------------------------=
 * decodeSection
 *=------------------------------------------------------------------------=
 * given a section of a message and a terminating separator (NULL ==> EOM),
 * go and get that section of message in it's decoded form and return it
 * in a big honkin' buffer.
 *
 * Parameter:
 *      MimeEncoding                - [in]  what format is it in?
 *      const char *                - [in]  the separator.  Null means look
 *                                      for the EOM marker, '.'
 *      int *                       - [out] the size of the attachment
 *      const char **               - [out] this section, fully decoded
 *
 * Output:
 *      ERRCODE
 */
ERRCODE decodeSection
(
    MimeEncoding encoding,
    const char *separator,
    int *size,
    const char **section
)
{
    /**
     * figure out what type of decoding it is, what the end separator is, 
     * and start workin'
     */
    switch (encoding) {
        case Base64:
            return base64Decode(separator, size, section);

        case Uuencode:
            return uuencodeDecode(separator, size, section);

        case QuotedPrintable:
            return quotedPrintableDecode(separator, size, section);

        case EightBit:
        case SevenBit:
            return sevenBitDecode(separator, size, section);

        default:
            fprintf(stderr, "Encoding I don't know about.  Treating it as plain text\n");
            return sevenBitDecode(separator, size, section);

    }

    // dead code
}


