/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#include <sanity.h>

#include <stdlib.h>
#include <string.h>

#include <miscutil.h>



const char *bytes = "bytes";
const char *kbytes = "KB";
const char *mbytes = "MB";


/**
 *=-------------------------------------------------------------------------=
 * copyStringImpl
 *=-------------------------------------------------------------------------=
 * Copies a string for a user using normal heap allocation routines.  The
 * CALLER is responsible for freeing this when they're done.
 *
 * Parameters:
 *      const char *        - [in] the string to be copied -- not touched.
 *
 * Output:
 *      char *              - the copy of the string.  CALLER FREES
 */
char *copyStringImpl
(
    char const *copyMe,
    char const *fileName,
    int lineNum
)
{
    int i = strlen(copyMe) + 1;
#if K_DEBUG
    char *newchar = (char *)localAllocImpl((char *)fileName, lineNum, i);
#else
    char *newchar = (char *)malloc(i);
#endif // K_DEBUG
    if (!newchar) return NULL;
    
    strncpy(newchar, copyMe, i);
    return newchar;
}


/**
 *=-------------------------------------------------------------------------=
 * printByteCount
 *=-------------------------------------------------------------------------=
 * given a byte count, print it in an appropraite format --- bytes, kb, mb
 * etc...
 *
 * Parameters:
 *      char *                  - [in]  buffer to put results in.
 *      int                     - [in]  max # chars to write.
 *      int                     - [in] value to convert.
 */
void printByteCount
(
    char *buf,
    int max,
    int value
)
{
    if (!buf) return;

    if (max < 10)  {
        *buf = '\0';
        return;
    }

    /**
     * If it can't be divided by 1k, then this is easy !
     */
    if ((value / 1024) == 0) {

        sprintf(buf, "%d %s", value, bytes);

    } else if ((value / 1048576) == 0) {

        /**
         * it's smaller than a MB!!!
         */
        sprintf(buf, "%d %s", (value / 1024), kbytes);

    }  else {

        /**
         * It's bigger than a MB
         */
        sprintf(buf, "%.2f %s", (double)value / 1024.0, mbytes);
    }
}



