/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#include <sanity.h>

#include <qfocusdata.h>

#include "mymultilineedit.h"



/**
 *=------------------------------------------------------------------------=
 * MyMultiLineEdit::MyMultiLineEdit
 *=------------------------------------------------------------------------=
 * constructor
 *
 * Parameters:
 *      QWidget *                   - [in]  our parent widget
 *      DealWithTabs                - [in]  how should we handle tabs?
 */
MyMultiLineEdit::MyMultiLineEdit
(
    QWidget *parent,
    DealWithTabs t
)
 : QMultiLineEdit(parent)
{
    tabHandling = t;
}


/**
 *=------------------------------------------------------------------------=
 * MyMultiLineEdit::~MyMultiLineEdit
 *=------------------------------------------------------------------------=
 * clean up!!
 */
MyMultiLineEdit::~MyMultiLineEdit()
{

}

/**
 *=------------------------------------------------------------------------=
 * MyMultiLineEdit::end
 *=------------------------------------------------------------------------=
 * goes to the end of the ctl, selecting text along the way if desired.
 *
 * Parameters:
 *      bool                        - [in]  optional -- do we select the text?
 */
void MyMultiLineEdit::end
(
    bool select
)
{
    QMultiLineEdit::end(select);
}

/**
 *=------------------------------------------------------------------------=
 * MyMultiLineEdit::hasMarkedText
 *=------------------------------------------------------------------------=
 * is there any marked text?
 *
 * Output:
 *      bool
 */
bool MyMultiLineEdit::hasMarkedText()
{
    return QMultiLineEdit::hasMarkedText();
}

/**
 *=------------------------------------------------------------------------=
 * MyMultiLineEdit::keyPressEvent
 *=------------------------------------------------------------------------=
 * a key has been pressed.  We are very interested in TAB characters.
 *
 * Parameters:
 *      QKeyEvent *                 - [in]  details, details, details
 */
void MyMultiLineEdit::keyPressEvent
(
    QKeyEvent *event
)
{
    if (!event) return;

    if (event->key() == Key_Tab) {

        switch (tabHandling) {
            case KeepTabChars:
                QMultiLineEdit::keyPressEvent(event);
                break;

            case TabsAreSpaces:
                if (!(event->state() & ShiftButton)) {
                    this->insert("    ", false);
                    break;
                }
                // fall through

            case TabToNext:
                focusData()->home();
                focusData()->next()->setFocus();
                break;
        }
    } else if (event->key() == Key_BackTab) {
        focusData()->home();
        focusData()->prev()->setFocus();
    } else {
        QMultiLineEdit::keyPressEvent(event);
    }
}



