/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#ifndef _MYMULTILINEEDIT_H_
#define _MYMULTILINEEDIT_H_


#include <qmultilineedit.h>


/**
 * For some extremely odd reason, Qt does not have a selectAll method 
 * publically available on the QMultiLineEdit, but there is a protected
 * one.  So, we've got this class to get around it.
 */
class MyMultiLineEdit : public QMultiLineEdit {

  public:
    enum DealWithTabs {
        KeepTabChars = 0,
        TabsAreSpaces,
        TabToNext
    };

    MyMultiLineEdit(QWidget *parent, DealWithTabs t = KeepTabChars);
    virtual ~MyMultiLineEdit();

    /**
     * These are routines that are protected on the real QMultiLineEdit 
     * class, but we want to expose them to more people.
     */
    bool hasMarkedText();
    void end(bool select = false);

  protected:
    void keyPressEvent(QKeyEvent *);


  private:
    DealWithTabs tabHandling;
};


#endif // _MYMULTILINEEDIT_H_


