/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#ifndef _NETAPIS_H_
#define _NETAPIS_H_


/**
 * This header defines the routines that we will use for the core of our
 * network operations.  A lot of these are just wrappers that have we have
 * developed/templated off the W. Richard Stevens code in "UNIX Network
 * Programming: Volume I".
 */



#include "ireader.h"


/**
 * A decent size chunk to read in at a time over the net.  POP3 has a limit of
 * 500 characters per line, and I believe SMTP's is somewhere around there to.
 * We are just going to give ourselves a bit of extra space in case we come
 * across a non-compliant implementation.
 */
const int NET_MAXLINELEN = 1024;

class NetworkReader : public IReader {

  public:
    NetworkReader(int socketfd, int timeoutinMS);
    virtual ERRCODE readLine(void *, unsigned int, int &cread);
//    virtual ERRCODE readLine(void *buf, unsigned int max, int timeout, int &cread);

  private:
    int connectionfd;
    int timeout;
};


ERRCODE networkConnect(const char *, int port, int *pdescriptor);
ssize_t networkRead(int, void *, size_t);
ssize_t networkReadLine(int, void *, size_t);
ssize_t networkWrite(int, const void *, size_t);
ERRCODE networkSocketHasData(int socketfd, int mswait);
ERRCODE networkRLSocketHasData(int socketfd, int mswait);

/**
 * These are used to log network traffic and other information.
 */
#define NET_LOG(msg) if (prefNetworkLog) fputs(msg, stderr)


#endif //_NETAPIS_H_


