/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#include <sanity.h>

#include <qlabel.h>
#include <qlineedit.h>
#include <qcheckbox.h>

#include "passworddlg.h"


/**
 *=------------------------------------------------------------------------=
 * PasswordDialog::PasswordDialog
 *=------------------------------------------------------------------------=
 * creates the pasword dialog and initializes everything.  Very exciting.
 *
 * Parameters:
 *      QWidget *               - [in]  parent widget.
 *      const char *            - [in]  account name
 *      const char *            - [in]  user name.
 */
PasswordDialog::PasswordDialog
(
    QWidget *parent,
    const char *acctName,
    const char *userName
)
: PasswordDlg(parent, "pwd", true, 0)
{
    this->accountL->setText(acctName);
    this->nameE->setText(userName);
}
 

/**
 *=------------------------------------------------------------------------=
 * PasswordDialog::~PasswordDialog
 *=------------------------------------------------------------------------=
 * clean up!
 */
PasswordDialog::~PasswordDialog()
{

}

/**
 *=------------------------------------------------------------------------=
 * PasswordDialog::accept
 *=------------------------------------------------------------------------=
 * makes sure that the user name field isn't empty.
 */
void PasswordDialog::accept()
{
    if (nameE->text().isEmpty()) return;

    /**
     * If it's not empty, proceed with normal processing.
     */
    PasswordDlg::accept();
}


/**
 *=------------------------------------------------------------------------=
 * PasswordDialog::getInput
 *=------------------------------------------------------------------------=
 * returns the values that the user selected.
 *
 * Parameters:
 *      const char *&               - [out] new name
 *      const char *&               - [out] new password
 *      bool &                      - [out] should this be remembered?
 *
 * Output:
 *      ERRCODE
 */
ERRCODE PasswordDialog::getInput
(
    const char * &newName,
    const char * &newPassword,
    bool & rememberPassword
)
{
    newName = copyString(nameE->text());
    if (!newName) return E_OUTOFMEMORY;
    if (!passwordE->text().isEmpty()) {
        newPassword = copyString(passwordE->text());
        if (!newPassword) {
            localFree(newName);
            newName = NULL;
            return E_OUTOFMEMORY;
        }
    }

    rememberPassword = rememberPasswordC->isChecked();
    return S_OK;
}


