/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#include <sanity.h>




#include "spool.h"



/**
 *=------------------------------------------------------------------------=
 * SpoolDownloader::createNew
 *=------------------------------------------------------------------------=
 * creates a new instance of this object and returns it.  You need to give
 * us a path.
 *
 * Parameters:
 *      const char *                - [in]  path
 *      SpoolDownloader * &         - [out] the new object.
 *
 * Output:
 *      ERRCODE
 */
ERRCODE SpoolDownloader::createNew
(
    const char *path,
    SpoolDownloader * & downloader
)
{
    /**
     * Create a new object and copy over the path, checking for memory 
     * conditions along the way.
     */
    downloader = new SpoolDownloader();
    if (!downloader) return E_OUTOFMEMORY;

    downloader->path = copyString(path);
    if (!download->path) {
        delete SpoolDownloader();
        return E_OUTOFMEMORY;
    }

    return S_OK;
}


/**
 *=------------------------------------------------------------------------=
 * SpoolDownloader::SpoolDownloader
 *=------------------------------------------------------------------------=
 * initializes a new instance of this class.  Don't ever call me directly, 
 * but use createNew() instaed.
 */
SpoolDownloader::SpoolDownloader()
{
    path = NULL;
    messageMax = -1;
}

/**
 *=------------------------------------------------------------------------=
 * SpoolDownloader::~SpoolDownloader
 *=------------------------------------------------------------------------=
 * it's cleanin' time!!!
 */
SpoolDownloader::~SpoolDownloader()
{
    if (handle) fclose(handle);
    localFree(path);
}

/**
 *=------------------------------------------------------------------------=
 * SpoolDownloader::connect
 *=------------------------------------------------------------------------=
 * to connect to the spool file, we need to be able to:
 *
 * a. open it.
 * b. lock it in some satisfactory way.  This should be fine on most file-
 *      system types, but there are some issues with NFS.  We'll first try
 *      locking using fcntl, and then if that doesn't work, we'll use a dot.
 *      file for locking.  It still won't work very well.
 *
 * Output:
 *      ERRCODE
 *
 * UNDONE: marcw, 2001-4-1 -- we need to put up a dialog SOMEWHERE warning
 *      users that locking on NFS doesn't work on a lot of older systems.
 */
ERRCODE SpoolDownloader::connect()
{
    
}

/**
 *=------------------------------------------------------------------------=
 * SpoolDownloader::login
 *=------------------------------------------------------------------------=
 * we don't have to actually do anything here.  Phew!!!
 *
 * Parameters:
 *      const char *                - [in]  name, ignored
 *      const char *                - [in]  password, ignored
 *      int                         - [in]  flags, ignored
 *
 * Output:
 *      ERRCODE                     - S_OK
 */
ERRCODE SpoolDownloader::login
(
    const char *,
    const char *,
    int
)
{
    return S_OK;
}


/**
 *=------------------------------------------------------------------------=
 * SpoolDownloader::getMessageInfo
 *=------------------------------------------------------------------------=
 * returns some information about the message store.  Specifically, the 
 * number of messages it contains and the total size of the message store.
 *
 * Parameters:
 *      int &                   - [out] count of messages.
 *      int &                   - [out] total size of store.
 *
 * Output:
 *      ERRCODE
 */
ERRCODE SpoolDownloader::getMessageInfo
(
    int &cmessages,
    int &totalSize
)
{

}


/**
 *=------------------------------------------------------------------------=

 *=------------------------------------------------------------------------=

