/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#ifndef _SPOOL_H_
#define _SPOOL_H_


#include "idownload.h"


/**
 *=------------------------------------------------------------------------=
 * This class implements our download functionality on a local mail spool
 * file.  We do all the appropriate stuff like file locking, etc ...
 */
class SpoolDownloader : public IDownload {

  public:
    static ERRCODE createNew(const char *path, SpoolDownloader * &pNew);
    virtual ~SpoolDownloader();

    /**
     * Implementation of IDownload
     */
    virtual ERRCODE connect();
    virtual ERRCODE login(const char *name, const char *passw, int flags);
    virtual ERRCODE getMessageInfo(int & cmessages, int &totalSize);
    virtual ERRCODE downloadMessage(int msg, bool del, MailMessage **);
    virtual ERRCODE deleteMessage(int msg);
    virtual ERRCODE purgeMessages();
    virtual ERRCODE disconnect();


  private:
    SpoolDownloader();

    /**
     * We need to save the path, and eventually, we'll have to know the max
     * number of messages in this session. We also need the file handle.
     */
    const char *path;
    FILE *handle;
    int messageMax;

    /**
     * Private routines we'll find useful.
     */
    ERRCODE countMessagesInSpool(int &);
};


#endif // _SPOOL_H_



