/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
#include <sanity.h>

#include <qobject.h>        // for SLOT()

/**
 * this file let us put our menu structure in a table, so we don't have write
 * a tonne of code for them, and it won't be so painful to change !!
 */
#include "accel.h"
#include "uiicons.h"
#include "uimenu.h"
#include "localized.h"



/** 
 * Our Main Application Menu
 */
MenuData applicationMenu [] = {

    { MENU_TOP_LEVEL, ID_FILE_MENU_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_FILE_SAVEMESSAGE_TEXT, filesaveIcon, false, SLOT(fileSave()), ACCEL_SAVE },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_FILE_IMPORTSTORE_TEXT, NULL, false, SLOT(fileImport()), 0 },
    { MENU_SEPARATOR, -1, NULL, false, NULL },
    { MENU_SUBMENU, ID_FILE_FOLDER_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_FILE_NEWFOLDER_TEXT, NULL, false, SLOT(fileFolderNew()), 0 },
    { MENU_ITEM, ID_FILE_COMPACTFOLDER_TEXT, NULL, false, SLOT(fileFolderCompact()), 0 },
    { MENU_ITEM, ID_FILE_COMPACTALL_TEXT, NULL, false, SLOT(fileCompactAll()), 0 },
    { MENU_ENDSUBMENU, -1, NULL, false, NULL, 0 },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_FILE_PRINT_TEXT, printsmIcon, false, SLOT(filePrint()), ACCEL_PRINT },
    { MENU_SEPARATOR, -1, NULL, false, NULL },
    { MENU_ITEM, ID_FILE_EXIT_TEXT, NULL, true, SLOT(closeAllWindows()), 0 },

    { MENU_TOP_LEVEL, ID_EDIT_MENU_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_EDIT_CUT_TEXT, NULL, false, SLOT(editCut()), ACCEL_CUT },
    { MENU_ITEM, ID_EDIT_COPY_TEXT, NULL, false, SLOT(editCopy()), ACCEL_COPY },
    { MENU_ITEM, ID_EDIT_PASTE_TEXT, NULL, false, SLOT(editPaste()), ACCEL_PASTE },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_EDIT_SEARCH_TEXT, NULL, false, SLOT(editSearch()), ACCEL_SEARCH },

    { MENU_TOP_LEVEL, ID_MESSAGE_MENU_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_MESSAGE_NEW_TEXT, newmailsmIcon, false, SLOT(messageNew()), ACCEL_NEW_MESSAGE },
    { MENU_ITEM, ID_MESSAGE_DELETE_TEXT, deletesmIcon, false, SLOT(messageDelete()), ACCEL_DELETE_MESSAGE },
    { MENU_ITEM, ID_MESSAGE_MOVE_TEXT, NULL, false, SLOT(messageMove()), ACCEL_MOVE_MESSAGE },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_MESSAGE_REPLY_TEXT, NULL, false, SLOT(messageReply()), ACCEL_REPLY },
    { MENU_ITEM, ID_MESSAGE_REPLYALL_TEXT, NULL, false, SLOT(messageReplyAll()), ACCEL_REPLY_ALL },
    { MENU_ITEM, ID_MESSAGE_FORWARD_TEXT, NULL, false, SLOT(messageForward()), ACCEL_FORWARD },

    { MENU_TOP_LEVEL, ID_ACCOUNTS_MENU_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_ACCOUNTS_DOWNLOAD_TEXT, NULL, false, SLOT(accountsDownload()), ACCEL_DOWNLOAD },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_ACCOUNTS_SHOW_TEXT, NULL, false, SLOT(accountsShow()), 0 },
    { MENU_SUBMENU, ID_ACCOUNTS_ADD_TEXT, NULL, false, NULL, 0 },
    { MENU_ENDSUBMENU, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_ACCOUNTS_REMOVE_TEXT, NULL, false, SLOT(accountsRemove()), 0 },

    { MENU_TOP_LEVEL, ID_TOOLS_MENU_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_TOOLS_GOTODEFAULT_TEXT, NULL, false, SLOT(toolsDefault()), ACCEL_DEFAULT },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_TOOLS_ADDRESSBOOK_TEXT, NULL, false, SLOT(showAddressBook()), ACCEL_ADDRESSBOOK },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_TOOLS_OPTIONS_TEXT, NULL, false, SLOT(toolsOptions()), 0 },
    
    { MENU_TOP_LEVEL, ID_HELP_MENU_TEXT, NULL, false, NULL, 0}, 
    { MENU_ITEM, ID_HELP_HELPME_TEXT, NULL, false, SLOT(helpHelpMe()), 0 },
    { MENU_ITEM, ID_HELP_HELP_TEXT, NULL, false, SLOT(helpHelp()), 0 },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_HELP_ABOUT_TEXT, NULL, false, SLOT(helpAbout()), 0 },

    { MENU_THATSALLFOLKS, -1, NULL, false, NULL, 0 }

};


MenuData mailEditWindowMenu [] = {

    { MENU_TOP_LEVEL, ID_FILE_MENU_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_FILE_NEW_TEXT, NULL, false, SLOT(fileNew()), ACCEL_NEW_MESSAGE },
    { MENU_ITEM, ID_FILE_SEND_TEXT, NULL, false, SLOT(fileSend()), ACCEL_SEND },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_FILE_SAVEMESSAGE_TEXT, NULL, false, SLOT(fileSave()), ACCEL_SAVE },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_FILE_PRINT_TEXT, NULL, false, SLOT(filePrint()), ACCEL_PRINT },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_FILE_CLOSE_TEXT, NULL, false, SLOT(fileClose()), 0 },

    { MENU_TOP_LEVEL, ID_EDIT_MENU_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_EDIT_CUT_TEXT, NULL, false, SLOT(editCut()), ACCEL_CUT },
    { MENU_ITEM, ID_EDIT_COPY_TEXT, NULL, false, SLOT(editCopy()), ACCEL_COPY },
    { MENU_ITEM, ID_EDIT_PASTE_TEXT, NULL, false, SLOT(editPaste()), ACCEL_PASTE },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_EDIT_SELECTALL_TEXT, NULL, false, SLOT(editSelectAll()), ACCEL_SELECTALL },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_SUBMENU, ID_EDIT_SEARCH_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_EDIT_FINDPERSON_TEXT, NULL, false, SLOT(editFindPerson()), 0 },
    { MENU_ITEM, ID_EDIT_FINDMSG_TEXT, NULL, false, SLOT(editFindMessage()), 0 },
    { MENU_ITEM, ID_EDIT_FINDTEXT_TEXT, NULL, false, SLOT(editFindText()), ACCEL_SEARCH },
    { MENU_ENDSUBMENU, -1, NULL, false, NULL, 0 },

    { MENU_TOP_LEVEL, ID_INSERT_MENU_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_INSERT_ATTACHMENT_TEXT, NULL, false, SLOT(insertAttachment()), 0 },
    { MENU_ITEM, ID_INSERT_TEXT_TEXT, NULL, false, SLOT(insertText()), 0 },

    { MENU_TOP_LEVEL, ID_MESSAGE_MENU_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_MSG_CHECKNAMES_TEXT, NULL, false, SLOT(messageCheckNames()), ACCEL_CHECKNAMES },
    { MENU_ITEM, ID_MSG_RECIPS_TEXT, NULL, false, SLOT(messageRecipients()), 0 },
    { MENU_ITEM, ID_MSG_ADDRESSBOOK_TEXT, NULL, false, SLOT(messageAddressBook()), ACCEL_ADDRESSBOOK },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_MSG_HIGH_TEXT, NULL, false, SLOT(messageHigh()), 0 },
    { MENU_ITEM, ID_MSG_MED_TEXT, NULL, false, SLOT(messageMedium()), 0 },
    { MENU_ITEM, ID_MSG_LOW_TEXT, NULL, false, SLOT(messageLow()), 0 },

    { MENU_TOP_LEVEL, ID_HELP_MENU_TEXT, NULL, false, NULL, 0}, 
    { MENU_ITEM, ID_HELP_HELPME_TEXT, NULL, false, SLOT(helpHelpMe()), 0 },
    { MENU_ITEM, ID_HELP_HELP_TEXT, NULL, false, SLOT(helpHelp()), 0 },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_HELP_ABOUT_TEXT, NULL, false, SLOT(helpAbout()), 0 },

    { MENU_THATSALLFOLKS, -1, NULL, false, NULL, 0 }
};

MenuData mailViewWindowMenu [] = {

    { MENU_TOP_LEVEL, ID_FILE_MENU_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_FILE_NEW_TEXT, NULL, false, SLOT(fileNew()), ACCEL_NEW_MESSAGE },
    { MENU_ITEM, ID_FILE_SAVEMESSAGE_TEXT, NULL, false, SLOT(fileSave()), ACCEL_SAVE },
    { MENU_ITEM, ID_FILE_SAVEATTACH_TEXT, NULL, false, SLOT(fileSaveAttach()), 0 },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_FILE_PRINT_TEXT, NULL, false, SLOT(filePrint()), ACCEL_PRINT },
    { MENU_SEPARATOR, -1, NULL, false, NULL,0 },
    { MENU_ITEM, ID_FILE_CLOSE_TEXT, NULL, false, SLOT(fileClose()), 0 },

    { MENU_TOP_LEVEL, ID_EDIT_MENU_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_EDIT_CUT_TEXT, NULL, false, SLOT(editCut()), ACCEL_CUT },
    { MENU_ITEM, ID_EDIT_COPY_TEXT, NULL, false, SLOT(editCopy()), ACCEL_COPY },
    { MENU_ITEM, ID_EDIT_PASTE_TEXT, NULL, false, SLOT(editPaste()), ACCEL_PASTE },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_EDIT_SELECTALL_TEXT, NULL, false, SLOT(editSelectAll()), ACCEL_SELECTALL },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_SUBMENU, ID_EDIT_SEARCH_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_EDIT_FINDPERSON_TEXT, NULL, false, SLOT(editFindPerson()), 0 },
    { MENU_ITEM, ID_EDIT_FINDMSG_TEXT, NULL, false, SLOT(editFindMessage()), 0 },
    { MENU_ITEM, ID_EDIT_FINDTEXT_TEXT, NULL, false, SLOT(editFindText()), ACCEL_SEARCH },
    { MENU_ENDSUBMENU, -1, NULL, false, NULL, 0 },

    { MENU_TOP_LEVEL, ID_VIEW_MENU_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_PREVIOUSMSG_TEXT, NULL, false, SLOT(viewPrevious()), ACCEL_PREVIOUS_MESSAGE },
    { MENU_ITEM, ID_NEXTMSG_TEXT, NULL, false, SLOT(viewNext()), ACCEL_NEXT_MESSAGE },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_ALLHEADERS_TEXT, NULL, false, SLOT(viewAllHeaders()), 0 },

    { MENU_TOP_LEVEL, ID_TOOLS_MENU_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_MSG_ADDRESSBOOK_TEXT, NULL, false, SLOT(toolsAddressBook()), ACCEL_ADDRESSBOOK },
    { MENU_ITEM, ID_ADD_TO_ADDRESS_BOOK_TEXT,NULL, false, SLOT(toolsAddToAddressBook()), 0 },

    { MENU_TOP_LEVEL, ID_MESSAGE_MENU_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_FILE_NEW_TEXT, NULL, false, SLOT(fileNew()),ACCEL_NEW_MESSAGE },
    { MENU_SEPARATOR, -1, NULL, false, NULL },
    { MENU_ITEM, ID_MESSAGE_REPLY_TEXT, NULL, false, SLOT(messageReply()), ACCEL_REPLY },
    { MENU_ITEM, ID_MESSAGE_REPLYALL_TEXT, NULL, false, SLOT(messageReplyAll()), ACCEL_REPLY_ALL },
    { MENU_ITEM, ID_MESSAGE_FORWARD_TEXT, NULL, false, SLOT(messageForward()), ACCEL_FORWARD },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_MESSAGE_DELETE_TEXT, NULL, false, SLOT(messageDelete()), ACCEL_DELETE_MESSAGE },

    { MENU_TOP_LEVEL, ID_HELP_MENU_TEXT, NULL, false, NULL, 0}, 
    { MENU_ITEM, ID_HELP_HELPME_TEXT, NULL, false, SLOT(helpHelpMe()), 0 },
    { MENU_ITEM, ID_HELP_HELP_TEXT, NULL, false, SLOT(helpHelp()), 0 },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_HELP_ABOUT_TEXT, NULL, false, SLOT(helpAbout()), 0 },

    { MENU_THATSALLFOLKS, -1, NULL, false, NULL, 0 }
};


MenuData addressBookMenu [] = {

    { MENU_TOP_LEVEL, ID_FILE_MENU_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_FILE_NEWADDRESS_TEXT, NULL, false, SLOT(fileNew()), ACCEL_NEW_ADDRESS },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_FILE_PROPERTIES_TEXT, NULL, false, SLOT(fileProperties()), 0 },
    { MENU_ITEM, ID_FILE_DELETE_TEXT, NULL, false, SLOT(fileDelete()), ACCEL_DEL_ADDRESS },
    { MENU_ITEM, ID_PRINT, NULL, false, SLOT(filePrint()), ACCEL_PRINT },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_SUBMENU, ID_FILE_IMPORT_TEXT, NULL, false, NULL, 0},
    { MENU_ENDSUBMENU, -1, NULL, false, NULL, 0 },
    { MENU_SUBMENU, ID_FILE_EXPORT_TEXT, NULL, false, NULL, 0},
    { MENU_ENDSUBMENU, -1, NULL, false, NULL, 0 },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_FILE_CLOSE_TEXT, NULL, false, SLOT(fileClose()), 0 },

    { MENU_TOP_LEVEL, ID_EDIT_MENU_TEXT, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_EDIT_CUT_TEXT, NULL, false, SLOT(editCut()), ACCEL_CUT },
    { MENU_ITEM, ID_EDIT_COPY_TEXT, NULL, false, SLOT(editCopy()), ACCEL_COPY },
    { MENU_ITEM, ID_EDIT_PASTE_TEXT, NULL, false, SLOT(editPaste()), ACCEL_PASTE },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_EDIT_SELECTALL_TEXT, NULL, false, SLOT(editSelectAll()), ACCEL_SELECTALL },

#if 0 // don't need just yet
    { MENU_TOP_LEVEL, ID_VIEW_MENU_TEXT, NULL, false, NULL, 0 },
#endif // 0

    { MENU_TOP_LEVEL, ID_HELP_MENU_TEXT, NULL, false, NULL, 0}, 
    { MENU_ITEM, ID_HELP_HELP_TEXT, NULL, false, SLOT(helpHelp()), 0 },
    { MENU_SEPARATOR, -1, NULL, false, NULL, 0 },
    { MENU_ITEM, ID_HELP_ABOUT_TEXT, NULL, false, SLOT(helpAbout()), 0 },

    { MENU_THATSALLFOLKS, -1, NULL, false, NULL, 0 }
};


