/*
 *  Copyright (C)  2000-2001 Marc Wandschneider <mw@kiltdown.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.
 *
 *  For more information look at the file COPYRIGHT in this package
 *
 */
/**
 * This holds a tonne of globals that control various user preferences, and 
 * the routines to load and save them.  Fweeeee!
 */
#include <sanity.h>

#include <qmainwindow.h>
#include <stdlib.h>
#include <sys/param.h>
#include <sys/stat.h>


#include "kiltdown.h"
#include <properties.h>
#include "userpref.h"

/**
 * This header file is here to help out those who are doing property file
 * loading and saving.
 */

typedef enum {
    TYPE_INT = 0,
    TYPE_STRING,
    TYPE_BOOLEAN,
    TYPE_FINISHED
} PROPERTYTYPE;

/**
 * this is used to drive our table of properties that are easy to load
 * and save. Harder ones can be done by hand.
 */
struct PropertyTable {
    const char *propName;
    void *propAddress;
    PROPERTYTYPE type;
};


/**
 * Main window preferences
 */
bool prefMainToolBarVisible = true;
bool prefMainStatusBarVisible = true;
QMainWindow::ToolBarDock prefMainToolBarLocation = QMainWindow::Top;
const char *prefDefaultAccount = NULL;
bool prefStartDownloadOnStart = true;

/**
 * Main window geometry
 */
int prefMainWindowLeft = 200;
int prefMainWindowTop = 200;
int prefMainWindowWidth = 640;
int prefMainWindowHeight = 480;

/**
 * Folderview preferences.
 */
const char *prefFolderViewCollapsed = NULL;

/**
 * Miscellaneous global preferences
 */
int prefFontScale = 0;


/**
 * Edit Window Geometry
 */
int prefEditWindowLeft = 200;
int prefEditWindowTop = 200;
int prefEditWindowWidth = 400;
int prefEditWindowHeight = 600;

/**
 * Edit Window Preferences
 */
bool prefEditShowCC = true;
bool prefEditShowBCC = true;

QMainWindow::ToolBarDock prefEditToolBarLocation = QMainWindow::Top;
bool prefEditToolBarVisible = true;
bool prefEditToolBarUsesBig = true;
bool prefEditToolBarShowLabels = true;

/**
 * Viewer Window Geometry
 */
int prefViewerWindowLeft = 200;
int prefViewerWindowTop = 200;
int prefViewerWindowWidth = 400;
int prefViewerWindowHeight = 600;

/**
 * Viewer Window Preferences
 */
bool prefViewerShowCC = true;
bool prefViewerShowBCC = true;

QMainWindow::ToolBarDock prefViewerToolBarLocation = QMainWindow::Top;
bool prefViewerToolBarVisible = true;
bool prefViewerToolBarUsesBig = true;
bool prefViewerToolBarShowLabels = true;

/**
 * Address BOok Window Geometry + preferences
 */
int prefAddressBookWindowLeft = 200;
int prefAddressBookWindowTop = 200;
int prefAddressBookWindowWidth = 500;
int prefAddressBookWindowHeight = 400;
QMainWindow::ToolBarDock prefAddressBookToolBarLocation = QMainWindow::Top;
bool prefAddressBookToolBarVisible = true;
bool prefAddressBookToolBarUsesBig = true;
bool prefAddressBookToolBarShowLabels = false;
int prefAddressBookNameFieldWidth = 150;
int prefAddressBookEmailFieldWidth = 150;
int prefAddressBookAddrFieldWidth = 125;
int prefAddressBookPhoneFieldWidth = 75;
const char *prefAddressBookPath = NULL;

/**
 * Misc preferences
 */
const char *prefAttachmentDir = NULL;

/**
 * Where network logs are written to.
 */
const char *prefNetworkLog = NULL;

/**
 * this is the big table of properties used to load and save them.  this is
 * far more efficient (and fewer bugs) than just doing them all by hand.
 */
struct PropertyTable propertyTable [] = {
    { "mainStatusBarVisible", (void *)&prefMainStatusBarVisible, TYPE_BOOLEAN },
    { "mainToolBarVisible", (void *)&prefMainToolBarVisible, TYPE_BOOLEAN },
    { "mainToolBarLocation", (void *)&prefMainToolBarLocation, TYPE_INT },
    { "activeAccount", (void *)&prefDefaultAccount, TYPE_STRING },
    { "startDownloadOnStart", (void *)&prefStartDownloadOnStart, TYPE_BOOLEAN },

    { "mainWindowLeft", (void *)&prefMainWindowLeft, TYPE_INT },
    { "mainWindowTop", (void *)&prefMainWindowTop, TYPE_INT },
    { "mainWindowWidth", (void *)&prefMainWindowWidth, TYPE_INT },
    { "mainWindowHeight", (void *)&prefMainWindowHeight, TYPE_INT },

    { "prefFolderViewCollapsed", (void *)&prefFolderViewCollapsed, TYPE_STRING },

    { "fontScale", (void *)&prefFontScale, TYPE_INT },

    { "editWindowLeft", (void *)&prefEditWindowLeft, TYPE_INT },
    { "editWindowTop", (void *)&prefEditWindowTop, TYPE_INT },
    { "editWindowWidth", (void *)&prefEditWindowWidth, TYPE_INT },
    { "editWindowHeight", (void *)&prefEditWindowHeight, TYPE_INT },

    { "editShowCC", (void *)&prefEditShowCC, TYPE_INT },
    { "editshowBCC", (void *)&prefEditShowBCC, TYPE_INT },
    { "editToolBarLocation", (void *)&prefEditToolBarLocation, TYPE_INT },
    { "editToolBarVisible", (void *)&prefEditToolBarVisible, TYPE_BOOLEAN },
    { "editToolBarUsesBig", (void *)&prefEditToolBarUsesBig, TYPE_BOOLEAN },
    { "editToolBarShowLabels", (void *)&prefEditToolBarShowLabels, TYPE_BOOLEAN },

    { "viewerWindowLeft", (void *)&prefViewerWindowLeft, TYPE_INT },
    { "viewerWindowTop", (void *)&prefViewerWindowTop, TYPE_INT },
    { "viewerWindowWidth", (void *)&prefViewerWindowWidth, TYPE_INT },
    { "viewerWindowHeight", (void *)&prefViewerWindowHeight, TYPE_INT },

    { "viewerShowCC", (void *)&prefViewerShowCC, TYPE_INT },
    { "viewershowBCC", (void *)&prefViewerShowBCC, TYPE_INT },
    { "viewerToolBarLocation", (void *)&prefViewerToolBarLocation, TYPE_INT },
    { "viewerToolBarVisible", (void *)&prefViewerToolBarVisible, TYPE_BOOLEAN },
    { "viewerToolBarUsesBig", (void *)&prefViewerToolBarUsesBig, TYPE_BOOLEAN },
    { "viewerToolBarShowLabels", (void *)&prefViewerToolBarShowLabels, TYPE_BOOLEAN },

    { "addressBookWindowLeft", (void *)&prefAddressBookWindowLeft, TYPE_INT },
    { "addressBookWindowTop", (void *)&prefAddressBookWindowTop, TYPE_INT },
    { "addressBookWindowWidth", (void *)&prefAddressBookWindowWidth, TYPE_INT },
    { "addressBookWindowHeight", (void *)&prefAddressBookWindowHeight, TYPE_INT },
    { "addressBookToolBarLocation", (void *)&prefAddressBookToolBarLocation, TYPE_INT },
    { "addressBookToolBarVisible", (void *)&prefAddressBookToolBarVisible, TYPE_BOOLEAN },
    { "addressBookToolBarUsesBig", (void *)&prefAddressBookToolBarUsesBig, TYPE_BOOLEAN },
    { "addressBookToolBarShowLabels", (void *)&prefAddressBookToolBarShowLabels, TYPE_BOOLEAN },
    { "addressBookNameFieldWidth", (void *)&prefAddressBookNameFieldWidth, TYPE_INT },
    { "addressBookEmailFieldWidth", (void *)&prefAddressBookEmailFieldWidth, TYPE_INT },
    { "addressBookAddrFieldWidth", (void *)&prefAddressBookAddrFieldWidth, TYPE_INT },
    { "addressBookPhoneFieldWidth", (void *)&prefAddressBookPhoneFieldWidth, TYPE_INT },
    { "addressBookPath", (void *)&prefAddressBookPath, TYPE_STRING },

    { "attachmentDirectory", (void *)&prefAttachmentDir, TYPE_STRING },

    { "networkLogFile", (void *)&prefNetworkLog, TYPE_STRING },

    { NULL, NULL, TYPE_FINISHED }
};


/**
 *=------------------------------------------------------------------------=
 * Private goo to this file
 *=------------------------------------------------------------------------=
 */
const char *kiltdownConfigFile = "kiltdown-config";
const char *configFilePath = NULL;

/**
 *=------------------------------------------------------------------------=
 * prefInit
 *=------------------------------------------------------------------------=
 * Loads in our preferences!!!
 *
 * Output:
 *      ERRCODE             - failure is fatal error.
 */
ERRCODE prefInit()
{
    PropertiesFile *mainProps;
    char tempBuf[MAXPATHLEN];
    ERRCODE er;
    int x;

    const char *svalue;
    bool bvalue;
    int ivalue;

    /**
     * Get the kiltdown directory.
     */
    er = Kiltdown::getKiltdownDirectory(tempBuf, sizeof(tempBuf));
    RETURN_ON_FAILURE(er);

    /**
     * Now get the config file name.
     */
    strcat(tempBuf, kiltdownConfigFile);
    configFilePath = copyString(tempBuf);
    if (!configFilePath) return E_OUTOFMEMORY;

    /**
     * 2. open the mail configuration file.  return if it doesn't exist.
     */
    er = PropertiesFile::openPropertiesFile(tempBuf, &mainProps, false);
    if (FAILED(er)) return S_OK;

    /**
     * Otherwise, we've got it, and it has something in it.  go and load in
     * some values now.
     */
    x = 0;
    while (propertyTable[x].type != TYPE_FINISHED) {

        switch (propertyTable[x].type) {

            case TYPE_INT:
                er = mainProps->getIntProperty(propertyTable[x].propName, &ivalue);
                if (er == S_OK)
                    *((int *)propertyTable[x].propAddress) = ivalue;
                break;

            case TYPE_BOOLEAN:
                er = mainProps->getBooleanProperty(propertyTable[x].propName, &bvalue);
                if (er == S_OK)
                    *((bool *)propertyTable[x].propAddress) = bvalue;
                break;

            case TYPE_STRING:
                er = mainProps->getStringProperty(propertyTable[x].propName, &svalue);
                if (er == S_OK)
                    *((const char **)propertyTable[x].propAddress) = svalue;
                break;

            default:
                K_FAIL("Oh my.  Bad property type in prefInit !!!!!");
                break;
        }
        x++;
    }

    mainProps->close();
    delete mainProps;

    /**
     * Put Custom load code here!!!!
     **/
    return S_OK;
}


/**
 *=------------------------------------------------------------------------=
 * prefTerm
 *=------------------------------------------------------------------------=
 * cleans up and saves out our prefernces.
 */
void prefTerm()
{
    PropertiesFile *configFile;
    ERRCODE er;
    int x;

    K_ASSERT(configFilePath, "configFilePath should NEVER be NULL !!!!!");

    er = PropertiesFile::openPropertiesFile(configFilePath, &configFile, true);
    localFree(configFilePath);
    if (FAILED(er)) {
        K_FAIL("Why on earth would opening a config file fail now???");
        return;
    }

    /**
     * whiz through the table and write out the current property values.  Note
     * that it's a bit of a pain for the application as it has to keep these
     * up to date, but it's the easiest way to do this.
     */
    x = 0;
    while (propertyTable[x].type != TYPE_FINISHED) {

        switch (propertyTable[x].type) {
            case TYPE_INT:
                configFile->writeIntProperty(propertyTable[x].propName,
                                            *((int *)propertyTable[x].propAddress));
                break;

            case TYPE_BOOLEAN:
                configFile->writeBooleanProperty(propertyTable[x].propName,
                                                 *((bool *)propertyTable[x].propAddress));
                break;

            case TYPE_STRING:
                configFile->writeStringProperty(propertyTable[x].propName,
                                                *((const char **)propertyTable[x].propAddress));
                break;

            default:
                K_FAIL("Oh my.  Bad property type in prefInit !!!!!");
                break;
        }
        x++;

    }

    configFile->close();
    delete configFile;

    /**
     * Write out/clean up any custom values here !!!!!
     **/


    /**
     * Whiz through the table looking for string properties, being sure to
     * clean them up!!!!
     */
    x = 0;
    while (propertyTable[x].type != TYPE_FINISHED) {
        if (propertyTable[x].type == TYPE_STRING
            && (*((const char **)propertyTable[x].propAddress) != NULL))
            localFree(*((const char **)propertyTable[x].propAddress));
        x++;
    }
}



